<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;

class VerificarAutenticacion
{
    public function handle(Request $request, Closure $next)
    {
        if (!session('usuario_autenticado')) {
            return redirect()->route('website.auth.login')->with('error', 'You must log in to access this page.');
        }

        // Obtener el tipo de usuario de la sesión
        $tipoUsuario = session('usuario_data')['tipo_usuario'];

        if ($tipoUsuario == 2 && $tipoUsuario == 3){
            return redirect()->route('website.auth.login')->with('error', 'Access denied due to construction.');
        }

        // Rutas permitidas según el tipo de usuario
        $rutasPermitidas = [
            1 => [
                'customer.home.index',
                'customer.orders.index',
                'customer.profile.index',
                'customer.orders.show',
                'customer.profile.address',
                'customer.profile.adressshow'
            ],
            2 => [
                'vendor.home.index',
                'vendor.orders.index',
                'vendor.products.index',
                'vendor.orders.show',
                'vendor.layouts.index',
                'vendor.profile.index'
            ],
            3 => [
                'agent.home.index',
                'agent.orders.index',
                'agent.profile.index'
            ]
        ];

        // Obtener el nombre de la ruta actual
        $nombreRuta = $request->route()->getName();

        // Verificar si la ruta está permitida para el tipo de usuario
        if (!in_array($nombreRuta, $rutasPermitidas[$tipoUsuario] ?? [])) {
            return redirect()->route('website.auth.login')->with('error', 'No tienes permiso para acceder a esta página.');
        }

        return $next($request);
    }
}
